.. image:: https://snakecdysis.readthedocs.io/en/latest/_images/snakecdysis_logo.png
   :target: https://snakecdysis.readthedocs.io/en/latest/_images/snakecdysis_logo.png
   :align: center
   :alt: Snakecdysis Logo

|PyPI version fury.io| |PyPI license|

|PyPI pyversions| |SnakemakeVersions| |Downloads|

.. contents:: Table of Contents
    :depth: 2

About Snakecdysis
=================

|readthedocs|

**Homepage:** `https://snakecdysis.readthedocs.io/en/latest/ <https://snakecdysis.readthedocs.io/en/latest/>`_


You want to wrapped your best snakemake workflow to be easy install and run, Snakecdysis is for you !!!!!

Citation
========

https://forge.ird.fr/phim/sravel/Snakecdysis

Maintainer
==========

* Sébastien RAVEL (CIRAD).

Thanks
======

Thanks to Valentin Guignon how find the name
Thanks to CulebrONT team's

License
=======

Licencied under `CeCill-C <http://www.cecill.info/licences/Licence_CeCILL-C_V1-en.html>`_ and MIT.

Intellectual property belongs to `CIRAD <https://www.cirad.fr/>`_ and authors.


.. |PyPI pyversions| image:: https://img.shields.io/pypi/pyversions/snakecdysis.svg
   :target: https://pypi.python.org/pypi/snakecdysis/

.. |SnakemakeVersions| image:: https://img.shields.io/badge/snakemake-≥6.10.0-brightgreen.svg
   :target: https://snakemake.readthedocs.io

.. |readthedocs| image:: https://pbs.twimg.com/media/E5oBxcRXoAEBSp1.png
   :target: https://snakecdysis.readthedocs.io/en/latest
   :width: 400px

.. |Downloads| image:: https://img.shields.io/pypi/dm/snakecdysis?color=orange&logo=snakecdysis-pypi
   :target: https://pypi.org/project/snakecdysis
   :alt: PyPi downloads

.. |PyPI version fury.io| image:: https://badge.fury.io/py/snakecdysis.svg
   :target: https://pypi.python.org/pypi/snakecdysis/

.. |PyPI license| image:: https://img.shields.io/pypi/l/snakecdysis.svg
   :target: https://pypi.python.org/pypi/snakecdysis/